/// <reference types="svelte" />
import { Map as ReactiveMap } from 'svelte/reactivity';
import { type TurboQuery, type TurboQueryOptions } from 'turbo-query';
/**
 * @description store instance query for query deduplication
 */
declare const instanceFactory: Map<string, TurboQuery>;
/**
 * @description store deps change over time , for query deduplication based on cache key on a app level for all queries with same key
 */
declare const DepsFactory: {
    [s in string]: Set<unknown>;
};
/**
 * @description store global cache for a cache key, reactive map so that all UI can be updated
 */
declare const globalCacheFactory: Map<string, {
    expiresAt: Date;
    item: any;
}>;
export declare const setQueryContext: () => {
    cacheFactory: ReactiveMap<unknown, unknown>;
    depsFactory: {};
    instanceFactory: Map<any, any>;
    instanceQueries: Map<any, any>;
};
export declare const getQueryContext: () => {
    cacheFactory: typeof globalCacheFactory;
    depsFactory: typeof DepsFactory;
    instanceFactory: typeof instanceFactory;
    instanceQueries: Map<TurboQuery, unknown>;
};
export declare const setQueryInstanceContext: () => Map<any, any>;
export declare const getQueryInstanceContext: () => Map<string, TurboQuery>;
export declare const setQueryCacheContext: () => Map<any, any>;
export declare const getQueryCacheContext: () => Map<string, {
    expiresAt: Date;
    item: any;
}>;
export declare const setQueryDepsStoreContext: () => {};
export declare const getQueryDepsStoreContext: () => {
    [x: string]: Set<unknown>;
};
type id = string | number | object;
export type normalized<key, value> = {
    ids: key[];
    /**
     * @description  typically the value contains an object keyed by id
     * @example {blog_id_1: blog_value,blog_id_2:blog_value,...}
     */
    value: object | Map<id, value>;
};
export declare function createQuery<TData, TError, TDeps, TMerged, TFinal>(props: {
    fetcher: (args: TDeps) => Promise<TData>;
    cacheKey: string;
    deps: () => TDeps;
    /**
     *
     * @param data original response from provided fetcher
     * @description  get unique id from the response, which can be used later to pick item from cache
     * @returns
     */
    pickId?: (data: TData) => (string | number)[];
    normalizer?: () => {};
    /**
     *
     * @description returned merged result will replace current cached item
     * @returns
     */
    mergeFn: (args: {
        Cached?: {
            expiresAt: Date;
            item: TMerged;
        };
        originalResponse: TData;
    }) => TMerged;
    pickFn: (args: {
        Cached: {
            expiresAt: Date;
            item: TMerged;
        };
        originalResponse: TData;
        ids: (string | number)[];
    }) => TFinal;
    onSuccess?: (data: {
        picked: TFinal;
        originalResponse: TData;
        cache: {
            expiresAt: Date;
            item: TMerged;
        };
    }) => void;
    onError?: (err: TError) => void;
    queryOptions?: TurboQueryOptions;
}): void | (() => {
    data: TFinal;
    isError: boolean;
    isRefetching: boolean;
    isLoading: boolean;
    isAborted: boolean;
    isSuccess: boolean;
    instance: TurboQuery;
    cacheInstance: () => unknown;
    refetch: () => Promise<void>;
    error?: Error | undefined;
});
export {};
